@@ -3,7 +3,7 @@
 
 #include "ulib/UUID.h"
 
-void uu_clear(struct uu1 *io);
+void uu_clear(struct_uu1_t *io);
 
 #endif
 /* ex:set ts=2 sw=2 itab=spaces: */
