@@ -4,7 +4,7 @@
 #include "ulib/UUID.h"
 
 IV uu_isnull_binary(const uu_t in);
-IV uu_isnull_struct(const struct uu1 *in);
+IV uu_isnull_struct(const struct_uu1_t *in);
 
 #endif
 /* ex:set ts=2 sw=2 itab=spaces: */
