@@ -8,7 +8,7 @@ extern "C" {
 }
 #endif
 
-IV uu_parse(const char *in, struct uu1 *out) {
+IV uu_parse(const char *in, struct_uu1_t *out) {
   int         i;
   const char  *cp;
   char        buf[3];
@@ -26,16 +26,16 @@ IV uu_parse(const char *in, struct uu1 *out) {
     if (!isxdigit(*cp))
       return -1;
   }
-  out->time_low              = strtoul(in, NULL, 16);
-  out->time_mid              = (U16)strtoul(in+9, NULL, 16);
-  out->time_high_and_version = (U16)strtoul(in+14, NULL, 16);
-  out->clock_seq_and_variant = (U16)strtoul(in+19, NULL, 16);
+  out->members.time_low              = strtoul(in, NULL, 16);
+  out->members.time_mid              = (U16)strtoul(in+9, NULL, 16);
+  out->members.time_high_and_version = (U16)strtoul(in+14, NULL, 16);
+  out->members.clock_seq_and_variant = (U16)strtoul(in+19, NULL, 16);
   cp = in+24;
   buf[2] = 0;
   for (i=0; i < 6; i++) {
     buf[0] = *cp++;
     buf[1] = *cp++;
-    out->node[i] = (U8)strtoul(buf, NULL, 16);
+    out->members.node[i] = (U8)strtoul(buf, NULL, 16);
   }
 
   return 0;
