@@ -3,7 +3,7 @@
 
 #include "ulib/UUID.h"
 
-void uu_unpack(const uu_t in, struct uu1 *out);
+void uu_unpack(const uu_t in, struct_uu1_t *out);
 
 #endif
 /* ex:set ts=2 sw=2 itab=spaces: */
