@@ -3,9 +3,9 @@
 
 #include "ulib/UUID.h"
 
-NV uu_time(const struct uu1 *in);
-UV uu_type(const struct uu1 *in);
-UV uu_variant(const struct uu1 *in);
+NV uu_time(const struct_uu1_t *in);
+UV uu_type(const struct_uu1_t *in);
+UV uu_variant(const struct_uu1_t *in);
 
 #endif
 /* ex:set ts=2 sw=2 itab=spaces: */
